==> SMILA-1.0-core-source.zip: org.eclipse.smila.jobmanager.test/code/src/org/eclipse/smila/jobmanager/test/AllTests.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2011 Attensity Europe GmbH and brox IT Solutions GmbH. All rights reserved. This program and the
 * accompanying materials are made available under the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: Andreas Schank (Attensity Europe GmbH) - initial implementation
 **********************************************************************************************************************/
package org.eclipse.smila.jobmanager.test;

import junit.framework.Test;
import junit.framework.TestSuite;

/** Test suite combining all tests for org.eclipse.smila.jobmanager bundle. */
public final class AllTests {

  /** Utility class: private constructor to prevent instantiation. */
  private AllTests() {
    ; // nothing
  }

  /** @return Test suite combining all tests for org.eclipse.smila.jobmanager.persistence.objectstore bundle. */
  public static Test suite() {
    final TestSuite suite = new TestSuite(AllTests.class.getName());
    // $JUnit-BEGIN$
    suite.addTestSuite(TestDataObjectTypeDefinition.class);
    suite.addTestSuite(TestBucketDefinition.class);
    suite.addTestSuite(TestParameterDefinition.class);
    suite.addTestSuite(TestWorkerDefinition.class);
    suite.addTestSuite(TestWorkflowDefinition.class);
    suite.addTestSuite(TestJobDefinition.class);
    suite.addTestSuite(TestDefinitionPersistence.class);
    suite.addTestSuite(TestJobManagerWithPersistence.class);
    suite.addTestSuite(TestValueExpression.class);
    suite.addTestSuite(TestJobListener.class);
    suite.addTestSuite(TestJobManagerException.class);
    suite.addTestSuite(TestJobManagerFinishTask.class);
    suite.addTestSuite(TestJobCanceling.class);
    suite.addTestSuite(TestWorkflowSimulation.class);
    suite.addTestSuite(TestWorkflowHandler.class);
    suite.addTestSuite(TestJobHandler.class);
    suite.addTestSuite(TestBucketHandler.class);
    suite.addTestSuite(TestDataObjectTypeHandler.class);
    suite.addTestSuite(TestWorkerHandler.class);
    suite.addTestSuite(TestComplexParametersInJob.class);
    suite.addTestSuite(TestJobRunUsingStores.class);
    suite.addTestSuite(TestJobRunWatcher.class);
    suite.addTestSuite(TestRunOnceTriggerTaskGenerator.class);
    suite.addTestSuite(TestJobRunModes.class);
    suite.addTestSuite(TestJobDependsOnRunningJob.class);
    // $JUnit-END$
    return suite;
  }

}

==> SMILA-1.1-core-source.zip: org.eclipse.smila.jobmanager.test/code/src/org/eclipse/smila/jobmanager/test/AllTests.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2011 Attensity Europe GmbH and brox IT Solutions GmbH. All rights reserved. This program and the
 * accompanying materials are made available under the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: Andreas Schank (Attensity Europe GmbH) - initial implementation
 **********************************************************************************************************************/
package org.eclipse.smila.jobmanager.test;

import junit.framework.Test;
import junit.framework.TestSuite;

/** Test suite combining all tests for org.eclipse.smila.jobmanager bundle. */
public final class AllTests {

  /** Utility class: private constructor to prevent instantiation. */
  private AllTests() {
    ; // nothing
  }

  /** @return Test suite combining all tests for org.eclipse.smila.jobmanager.persistence.objectstore bundle. */
  public static Test suite() {
    final TestSuite suite = new TestSuite(AllTests.class.getName());
    // $JUnit-BEGIN$
    suite.addTestSuite(TestDataObjectTypeDefinition.class);
    suite.addTestSuite(TestBucketDefinition.class);
    suite.addTestSuite(TestParameterDefinition.class);
    suite.addTestSuite(TestWorkerDefinition.class);
    suite.addTestSuite(TestWorkflowDefinition.class);
    suite.addTestSuite(TestJobDefinition.class);
    suite.addTestSuite(TestDefinitionPersistence.class);
    suite.addTestSuite(TestJobManagerWithPersistence.class);
    suite.addTestSuite(TestValueExpression.class);
    suite.addTestSuite(TestJobListener.class);
    suite.addTestSuite(TestJobManagerException.class);
    suite.addTestSuite(TestJobManagerFinishTask.class);
    suite.addTestSuite(TestJobCanceling.class);
    suite.addTestSuite(TestWorkflowSimulation.class);
    suite.addTestSuite(TestWorkflowHandler.class);
    suite.addTestSuite(TestJobHandler.class);
    suite.addTestSuite(TestBucketHandler.class);
    suite.addTestSuite(TestDataObjectTypeHandler.class);
    suite.addTestSuite(TestWorkerHandler.class);
    suite.addTestSuite(TestComplexParametersInJob.class);
    suite.addTestSuite(TestJobRunUsingStores.class);
    suite.addTestSuite(TestJobRunWatcher.class);
    suite.addTestSuite(TestRunOnceTriggerTaskGenerator.class);
    suite.addTestSuite(TestJobRunModes.class);
    suite.addTestSuite(TestJobDependsOnRunningJob.class);
    suite.addTestSuite(TestDefaultCompletionTasksGeneration.class);
    suite.addTestSuite(TestJobManagerJobCompletingWorkflowRun.class);
    // $JUnit-END$
    return suite;
  }

}
